@@ -235,8 +235,12 @@ class BeakerxCheckboxGroup(EasyFormComponent):
     def __init__(self, **kwargs):
         super(BeakerxCheckboxGroup, self).__init__(**kwargs)
 
+    def __set_value(self, new_value):
+        for item in self.children:
+            item.value = item.description in new_value
+
     children = []
-    value = property(lambda self: [item.description for item in self.children if item.value])
+    value = property(lambda self: [item.description for item in self.children if item.value], __set_value)
 
     def addChildren(self, children):
         self.children.append(children)
